Meteor defense project

Dependencies:   N5110 mbed

Revision:
45:1a013017ae92
Parent:
44:aa086363d09f
Child:
46:abb046536524
--- a/GameEngine/GameEngine.h	Wed May 03 21:00:43 2017 +0000
+++ b/GameEngine/GameEngine.h	Wed May 03 23:41:41 2017 +0000
@@ -18,7 +18,11 @@
     char cArr[Cols][Rows];  
 };
 
-
+/** GameEngine Class
+@brief Main library for the game
+@author JianWei Lee
+@date April 2017
+*/
 class GameEngine
 {
     
@@ -28,51 +32,49 @@
     
     /**Initialise GameEngine
     *
     *Set the number of life at every level to 3
     *To initialise all the variables of Weapons and Spawns
     *@param w - the current number level
     */
     void init(int w);
     
     /**Update game
     *
     *This is where all the gameplay and drawing is gathered
     *The only way to lose this game is when the spawns reaches the player side (y = 46) for 3 times in a wave
     *Lights up LEDs according to number of lifes left
     */
     void update(Gamepad &pad, N5110 &lcd);
     
     /**Weapon Upgrades
     *
     *Weapon upgrade will happen everytime after completing a game wave
     *This function connects class GUI and Weapons to display weapon levels and confirm upgrades
     */
     void weapUpgrade(Gamepad &pad, N5110 &lcd);
     
     /**Starting Menu
     *
     *Few strings to be printed on the lcd before starting the game
     *Light up LEDs in a knight rider pattern
     */
     void startingMenu(Gamepad &pad, N5110 &lcd);
     
     /**Update retry.Arr & retry.cArr
     *
     *retry.Arr and retry.cArr is always updated at the start of a wave.
     *To make a copy of the main array
     */
     void update_MainToRetry();
     
-    /**Update main array using retry array
+    /**Update Main array using Retry array
     *
-    *this function will be used when player decided to retry the game 
+    *@brief To make a copy of the Retry array to Main array
     */
     void update_RetryToMain();
     
     /**Reset the game
     *
-    *Only thing requires reset is the array and weapon's variables
-    *Happens when player give up on the game
+    *@brief Only thing that resets is the array and weapon's variables
     */
     void reset_Game();
@@ -28,51 +32,49 @@
     /**Initialise GameEngine
     *
-    *Set the number of life at every level to 3
-    *To initialise all the variables of Weapons and Spawns
+    *@brief Set the number of life at every level to 3
+    *@brief To initialise all the variables of Weapons and Spawns
     *@param w - the current number level
     */
@@ -28,51 +32,49 @@
     /**Update game
     *
-    *This is where all the gameplay and drawing is gathered
-    *The only way to lose this game is when the spawns reaches the player side (y = 46) for 3 times in a wave
-    *Lights up LEDs according to number of lifes left
+    *@brief This is where all the gameplay and drawing is gathered
+    *@brief The only way to lose this game is when the spawns reaches the player side (y = 46) for 3 times in a wave
+    *@brief Lights up LEDs according to number of lifes left
     */
     void update(Gamepad &pad, N5110 &lcd);
@@ -28,51 +32,49 @@
     /**Weapon Upgrades
     *
-    *Weapon upgrade will happen everytime after completing a game wave
-    *This function connects class GUI and Weapons to display weapon levels and confirm upgrades
+    *@brief Weapon upgrade will happen everytime after completing a game wave
+    *@brief This function connects class GUI and Weapons to display weapon levels and confirm upgrades
     */
     void weapUpgrade(Gamepad &pad, N5110 &lcd);
@@ -28,51 +32,49 @@
     /**Starting Menu
     *
-    *Few strings to be printed on the lcd before starting the game
-    *Light up LEDs in a knight rider pattern
+    *@brief Few strings to be printed on the lcd before starting the game
+    *@brief Light up LEDs in a knight rider pattern
     */
     void startingMenu(Gamepad &pad, N5110 &lcd);
@@ -28,51 +32,49 @@
     void startingMenu(Gamepad &pad, N5110 &lcd);
     
-    /**Update retry.Arr & retry.cArr
+    /**Update Retry array using Main array
     *
@@ -28,51 +32,49 @@
     *
-    *retry.Arr and retry.cArr is always updated at the start of a wave.
-    *To make a copy of the main array
+    *@brief To make a copy of the Main array to Retry array
     */
     void update_MainToRetry();